@@ -1,4 +1,4 @@
-from statistics import mean
+from statistics import mean, mode
 
 from shameni import Gaze
 from namari import Namari
@@ -27,7 +27,7 @@ class Wimby:
     
     def dump(self):
         if self.movers.count() > 0:
-            print("Wimby Cyrpocurrency Analysis")
+            print("Wimby Cryptocurrency Analysis")
             print("\n[NOTES]")
             print("A. Do your own research")
             print("B. Trade at your own risk")
@@ -43,20 +43,22 @@ class Wimby:
             print("        - Suggestive to STRONGLY BUY at your discretion")
             print("    * The more positive trends up to the rightmost WAVGs mean successive upward price movement.")
             print("        - Suggestive to STRONGLY SELL at your discretion")
-            print("5. Your probable last metric would be on the Coinbase application.")
+            print("5. Your last metric would be on the Coinbase application.")
             print("    * More than 80% Sell Trend is suggestive to STRONGLY SELL at your discretion.")
             print("    * More than 60% Sell Trend is suggestive to SELL at your discretion.")
             print("    * More than 60% Buy Trend is suggestive to HOLD or strategic BUY at your discretion.")
             print("    * More than 80% Buy Trend is suggestive to HOLD or STRONGLY  BUY at your discretion.")
-            print("6. Use the three (3) metrics to trade or hold strategically.")
+            print("6. Use the three (3) metrics to hold or trade strategically.")
             print("\n[WAVG Analytics]")
             ranking = list(sorted([float(x) for x in self.movers.keys()]))
             minn = len(str(int((min(ranking) * 100)))) + 3
             maxn = len(str(int((max(ranking) * 100)))) + 3
             padding = max([maxn, minn])
+            market_trend = []
             for rank in ranking:
                 tokens = self.movers.get(str(rank), [])
                 movement = rank * 100
+                market_trend.append(movement)
                 for token in tokens:
                     fmovement = f"{movement:,.2f}"
                     while len(fmovement) < padding:
@@ -65,6 +67,11 @@ class Wimby:
                     pattern = self.momentum.get(token, {}).get("trend", "")
                     if pattern.strip() != "":
                         print(f"    {pattern}")
+            trend_avg = mean(market_trend)
+            trend_mode = mode(market_trend)
+            print("\n[Market Trends]")
+            print(f" - Average Trend: {trend_avg:,.2f}%")
+            print(f" - Common Trend: {trend_mode:,.2f}%")
 
 def _supported(coins, aliases, aliased, debug):
     supported = []
